@@ -248,7 +248,7 @@ def viperproducetotopicstream(vipertoken,host,port,topic,producerid,offset,enabl
     return val
 
 def vipercreatetrainingdata(vipertoken,host,port,consumefrom,produceto,dependentvariable,independentvariables,
-                            consumerid,producerid,offset,companyname,enabletls=0,delay=100,maxrows=-1,brokerhost='',brokerport=-999,microserviceid=''):
+                            consumerid,producerid,offset,companyname,partition=-1,enabletls=0,delay=100,maxrows=-1,brokerhost='',brokerport=-999,microserviceid=''):
 
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(consumefrom)==0 or len(produceto)==0 or len(dependentvariable)==0 or
         len(independentvariables)==0 or len(companyname)==0 or len(consumerid)==0 or len(producerid)==0):
@@ -256,7 +256,7 @@ def vipercreatetrainingdata(vipertoken,host,port,consumefrom,produceto,dependent
         
     value=("createtrainingdata?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto="+produceto +
            "&dependentvariable="+dependentvariable+"&independentvariables="+independentvariables +"&offset="+str(offset)+
-           "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&consumerid="+consumerid + "&producerid="+producerid+"&companyname="+companyname + "&maxrows="+str(maxrows) + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
+           "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&partition="+str(partition)+"&consumerid="+consumerid + "&producerid="+producerid+"&companyname="+companyname + "&maxrows="+str(maxrows) + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
